/*
 * Bull SAS / OW2 Orchestra
 * Copyright (C) 2011 Bull S.A.S, and individual contributors as indicated
 * by the @authors tag.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

package org.ow2.orchestra.designer.fileNavigator;

/**
 * This class holds access permissions a user have on a process
 *
 * @author diouf-a
 */
public class UserAccessPermissions {

  private String user;
  private boolean writing;
  private boolean reading;
  private boolean admin;
  private boolean deleting;


  public UserAccessPermissions() {
    this.user = "";
    this.writing = false;
    this.reading = false;
    this.admin = false;
    this.deleting = false;
  }

  public String getUser() {
    return this.user;
  }

  public boolean getReading() {
    return this.reading;
  }

  public boolean getWriting() {
    return this.writing;
  }

  public boolean getAdmin() {
    return this.admin;
  }

  public boolean getDeleting() {
    return this.deleting;
  }

  public void setUser(String user) {
    this.user = user;
  }

  public void setReading(boolean reading) {
    this.reading = reading;
  }

  public void setWriting(boolean writing) {
    this.writing = writing;
  }

  public void setAdmin(boolean admin) {
    this.admin = admin;
  }

  public void setDeleting(boolean deleting) {
    this.deleting = deleting;
  }

  /**
   * update the accesses permission
   *
   * @param lAccess a semicolon separated list of boolean values for respectively:
   *                reading;writing;deleting;admin permissions
   */
  public void updateAccess(String lAccess) {
    String[] tabAccess = lAccess.split(";");
    this.setReading(tabAccess[0].equals("true"));
    this.setWriting(tabAccess[1].equals("true"));
    this.setDeleting(tabAccess[2].equals("true"));
    this.setAdmin(tabAccess[3].equals("true"));
  }

  /**
   * User access permissions in the following format:<br/>
   * <p>user:reading;writing;deleting;admin</p>
   * Except for user which is a string other values are boolean
   *
   * @return
   */
  @Override
  public String toString() {
    return this.getUser() + ":" + this.getReading() + ";" + this.getWriting() + ";" + this.getDeleting() + ";"
        + this.getAdmin();
  }
}
